"""Cavity objects."""
from circadapt.components import Component


class Cavity(Component):
    """Basic Cavity object."""

    parameters = [
        ]

    signals = [
        'A',
        'p',
        'p_trans',
        'q',
        'V',
        'VDot'
        ]


class Bag(Component):
    """Basic Bag object."""

    parameters = [
        'k',
        'VRef',
        'Sfperi',
        ]

    signals = [
        'V',
        'p',
        ]


class Tube0D(Component):
    """
    Tube0D is a 0D cavity.

    The volume of the Tube0D is given by the cross-sectional area multiplied by
    its length.

    Parameters
    ----------
    Len: double
        Length of the tube
    AWall: double
        Cross-sectional area of the wall
    k: double
        Stiffness coefficient of the wall
    p0: double
        Pressure at A=A0
    A0: double
        Cross-sectional cavity area for p=p0

    Signals
    -------
    V: array
        Volume
    p: array
        Pressure
    """

    parameters = [
        'Len',
        'AWall',
        'k',
        'p0',
        'A0',
        ]

    signals = [
        'V',
        'p',
        ]


class Chamber2022(Component):
    """Chamber2022 object."""

    parameters = [
        'bucklingFunction',
        ]

    signals = [
        'V',
        'p',
        'V',
        'VDot',
        'A',
        'Y',
        'q',
        ]


class TriSeg2022(Component):
    """TriSeg2022 object."""

    parameters = [
        'tau',
        ]

    signals = [
        'V',
        'Y',
        'V0',
        'Y0',
        'VDot',
        'YDot',
        'nLoop',
        'Fp',
        'Fv',
        ]
